#
# spec file for package solaar
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           solaar
Version:        1.1.0
Release:        bp154.1.81
Summary:        Linux devices manager for the Logitech Unifying Receiver
License:        GPL-2.0-or-later
Group:          Hardware/Other
URL:            https://pwr-solaar.github.io/Solaar
Source0:        Solaar-%{version}.tar.gz
#PATCH-FIX-OPENSUSE solaar-fix-desktop-categories.patch malcolmlewis@opensuse.org -- Fix desktop categories as per openSUSE desktop file specification.
Patch0:         solaar-fix-desktop-categories.patch
#
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  python-rpm-macros
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
#
BuildRequires:  python3-gobject
Requires:       python3-gobject
BuildRequires:  python3-gobject-Gdk
Requires:       python3-gobject-Gdk
BuildRequires:  python3-PyYAML
Requires:       python3-PyYAML
Requires:       python3-pyudev
BuildRequires:  typelib-1_0-Gtk-3_0
Requires:       typelib-1_0-Gtk-3_0
#
Requires:       solaar-udev >= %{version}
#
Obsoletes:      solaar-cli < %{version}
Provides:       solaar-cli = %{version}
#
BuildArch:      noarch

%description
Solaar will detect all devices paired with your Unifying Receiver, and
at the very least display some basic information about them.

For some devices, extra settings (usually not available through the
standard Linux system configuration) are supported. For a full list of
supported devices and their features, see docs/devices.md.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/Other

%description    doc
Solaar will detect all devices paired with your Unifying Receiver, and
at the very least display some basic information about them.

For some devices, extra settings (usually not available through the
standard Linux system configuration) are supported. For a full list of
supported devices and their features, see docs/devices.md.

%package        udev
Summary:        Udev rules for accessing Logitech Unifying Receiver
Group:          Hardware/Other
Requires:       udev
Conflicts:      solaar-cli < %{version}

%description    udev
Rules that users are able to access Logitech Unifying Receiver.

%prep
%autosetup -p1 -n Solaar-%{version}

# Fix desktop file installation
sed -i '/yield autostart_path/d' setup.py

%build
sed -i 's#/usr/bin/env python##' lib/solaar/gtk.py lib/solaar/tasks.py
%python3_build

%install
%python3_install
%fdupes %{buildroot}%{python3_sitelib}
%fdupes -s %{buildroot}%{_datadir}
%suse_update_desktop_file %{buildroot}%{_datadir}/applications/%{name}.desktop

install -d 0755 %{buildroot}%{_udevrulesdir}
install -m 0644 rules.d/42-logitech-unify-permissions.rules %{buildroot}%{_udevrulesdir}/42-logitech-unify-permissions.rules

ln -s solaar %{buildroot}%{_bindir}/solaar-cli

%posttrans udev
# This is needed to apply permissions to existing devices when the package is
# installed.
/usr/bin/udevadm trigger --subsystem-match=hidraw --action=add

%files
%doc ChangeLog COPYRIGHT
%license COPYING
%{_bindir}/%{name}
%{_bindir}/%{name}-cli
%{_datadir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/scalable/apps/solaar.svg
%{_datadir}/metainfo/io.github.pwr_solaar.solaar.metainfo.xml
%{python3_sitelib}/hidapi
%{python3_sitelib}/logitech_receiver
%{python3_sitelib}/solaar
%{python3_sitelib}/solaar-*

%files udev
%{_udevrulesdir}/42-logitech-unify-permissions.rules

%files doc
%defattr(-,root,root)
%doc docs/*

%changelog
* Sat Nov 27 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.1.0
  * https://github.com/pwr-Solaar/Solaar/blob/1.1.0/ChangeLog
- Add missing dependency to python3-PyYAML - bso#1193123
* Mon Oct 25 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.7
  * https://github.com/pwr-Solaar/Solaar/blob/1.0.7/ChangeLog
* Sun Jun  6 2021 Dirk Müller <dmueller@suse.com>
- update to 1.0.6:
  * Update sliding DPI to look for suitable keys
  * Add mouse gestures that can trigger rules
  * Complain if receivers do not support connection notification
  * In polling rate setting, only modify onboard profiles when actually writing polling rate
  * Add ability to ignore settings.
  * Use symbols for receiver sub-registers
  * Add support for wired G700
  * Do not set attention icon
  * Replace deprecated GTK stock menu icons
  * Better handling of icons in tray and tray menus
  * Receiver c52e does not unpair
  * Match active WM_CLASS as well as active process name in rules
  * Correctly set icon theme value when regular battery icons are not available
  * Handle exception when device is not available when device is being added
  * Perform initial activation of devices in listener threads
  * Keep track of serial numbers in the configuration file
  * Don't update settings for non-active devices
  * Set the current host name if not stored on the device
  * Add setting for SMART SHIFT ENHANCED feature
  * Don't unnecessarily use long messages for HID++ 1.0 commands
  * Correctly select choices in solaar config and use 1-origin addressing
  * Add quirk for G915 TKL keyboard because its host mode inteferes with its Fn keys
  * Show command outputs both saved and on-device settings
  * Update documentation
  * Fix bug in hidconsole
  * Update French translation
* Wed Jun  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Fix the %%doc files. README.md is a symlink to
  'docs/index.md'. Let's use this file directly.
* Sat Feb 27 2021 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.5
  * Update documentation on devices forgetting settings.
  * Improve help messages
  * Fix bug in finding receiver to pair
  * Solaar config command can set keyed settings.
* Thu Oct 22 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.4
  * Support USB and BT connected devices that are not in descriptors.py
  * Use FRIENDLY NAME for codename if needed and available.
  * Extract manufacturer and product ID from Udev HID information.
  * Add Bluetooth and USB product IDs to device descriptors records.
  * Support Bluetooth-connected devices.
  * Add model ID and unit ID to device identification.
  * Support changing DPI by pressing DPI Switch button and sliding horizontally
  * Add device-specific notification handlers.
  * Add MX Vertical USB information.
  * Udev rule adds seat permissions for all Logitech devices.
  * Support USB-connected devices in GUI.
  * Make probe and config work for USB-connected devices.
  * Improve strings and display for settings.
  * Correctly handle non-unifying connection notifications.
  * Update GUI strings for several settings.
  * Better support for EX100 and devices that connect to it.
  * Partial support for feature GESTURE_2.
  * Simplify interface for settings.
  * Use DJ connection notifications to set device active status
  * Udev rule sets seat write permissions for hidraw nodes for device as well as receivers.
  * Handle USB devices that use HID++ protocol in CLI.
  * Use device hidraw nodes where possible.
  * Handle receivers with serial numbers that don't provide number of pairings.
  * Ignore exceptions when setting locale.
  * Correctly discover settings that share a name.
  * Don't show pop-up notifications at startup.
  * Keep battery voltage updated in GUI.
  * Add Portugese translation.
  * Update several translations.
  * Add Lightspeed receivers c545 and c541.
  * Reimplement REPROG_CONTROLS data structure.
* Mon Aug  3 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.3
  * Remove deprecated solaar-cli application.
  * Don't install udev or autostart files from python (or pip).
  * Solaar needs Python 3.6+ and probably needs kernel 5.2+
  * Handle exceptions on dynamic settings when device is not connected.
  * Fix inifinite loop on some low-level write errors
  * Add support for EX100 keyboard/mouse and receiver (046d:c517)
  * Add two settings for THUMB_WHEEL feature - inversion and reporting via HID++
  * Update German translation
  * Use REPORT RATE feature when available to determine polling rate.
  * Improve config command speed when not printing all settings
  * Improve config command handling and checking of arguments
  * Add setting for CHANGE_HOST feature
  * Add argument to settings for values that are not to persist
  * Add argument to settings to not wait for reply when writing a value to device
  * Add argument to not wait for reply from request to device
  * Add settings for MULTIPLATFORM and DUALPLATFORM features
  * Remove Logitech documents from documentation directory
  * Change config command to not read all settings when only printing or showing one
  * Display hosts info in 'solaar show' if device supports it
  * Remove non-working smooth-scrool from M510 v1
  * Add yapf and flake8 code style checks
  * Fix feature k375s Fn inversion
  * Update controls (keys and buttons) and tasks (actions)
  * Improved way to specify feature settings.
  * Don't abort on device notifications with unexpected device numbers, just warn.
  * Keep track of non-features so as not to ask device multiple times.
  * Implement KEYBOARD DISABLE KEYS feature.
  * Don't create notifications for DJ device activity reports.
  * Update a few special keys and actions.
  * Add keyed choice settings in configuration panel.
  * Support remappable keys from reprogrammable keys v4 feature.
  * Add setting class for keyed choice.
  * Only check for features once per device.
  * Use settings interface to show feature values in solaar show if no special code for feature.
  * Remove maximum window size.
  * Process battery voltage notifications.
  * Display battery voltage information in main window if regular battery information not available.
  * Show next battery level where available.
  * Update list of implemented features and provide information on how to implement features.
  * Add c53d as a Lightspeed receiver.
* Sat May 23 2020 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.2
- Removed 0001-Fix-reading-and-storing-DPI-in-config-settings.patch
- Removed 0001-data-fix-icon-theme-for-battery-level.patch
- Removed 0005-notifications-fix-battery-status-notification-parsin.patch
* Thu Oct  3 2019 Andreas Schneider <asn@cryptomilk.org>
- Add missing Requries for python3-gobject-Gdk
* Wed Sep 18 2019 Andreas Schneider <asn@cryptomilk.org>
- Apply udev rules to existing devices
* Tue Sep 17 2019 Andreas Schneider <asn@cryptomilk.org>
- Fix icon theme for battery level
  + Added 0001-data-fix-icon-theme-for-battery-level.patch
- Fix battery status notifaction parsing
  + Added 0005-notifications-fix-battery-status-notification-parsin.patch
* Thu Aug 22 2019 Andreas Schneider <asn@cryptomilk.org>
- Add a conflict with solaar-cli to solar-udev
* Thu Aug  1 2019 Andreas Schneider <asn@cryptomilk.org>
- Fix reading and storing DPI settings
  + Added 0001-Fix-reading-and-storing-DPI-in-config-settings.patch
* Sat Jul 27 2019 Andreas Schneider <asn@cryptomilk.org>
- Update to version 1.0.1:
  * Updated the repo url.
  * Fixed typo which was crashing the application.
  * Improved the HID write routine which was causing issues on some devices.
  * Fix non-unifying receivers in Linux 5.2.
  * Add new Lightspeed receiver (used in the G305)
- Updates from version 1.0.0:
  * First major release after 6 years
  * Support for a lot of new mice and keyboards
* Tue Jun 10 2014 dmitry_r@opensuse.org
- Disable autostart options in setup script
* Wed May  7 2014 dmitry_r@opensuse.org
- Split CLI to separate package
- Add runtime requirements
- Use original udev rules
* Tue Aug  6 2013 malcolmlewis@opensuse.org
- Updated to version 0.9.2:
  + Added support for hand detection on the K800.
  + Added support for V550 and V450 Nano.
  + Fixed side-scrolling wit the M705 Marathon.
  + Fixed identification of the T650 Touchpad.
  + Added internationalization support and romanian translation.
  + Polish translation courtesy of Adrian Piotrowicz.
- Updates from version 0.9.1:
  + When devices report a battery alert, only show the alert once.
  + Make sure devices in the window tree are sorted by registration
    index.
  + Added an autostart .desktop file.
  + Replaced single-instance code with GtkApplication.
  + Fixed indentification of the M505 mouse.
  + Fixed an occasional windowing layout bug with the C52F Nano
    Receiver.
- Updates from version 0.9.0:
  + New single-window UI.
  + Performance MX leds show the current battery charge.
  + Support the VX Nano mouse.
  + Faster and more accurate detection of devices.
  + If upower is accessible through DBus, handle suspend/resume.
  + Replaced Solaar icons with SVGs.
  + Running solaar-cli in parallel with solaar is now less likely
    to cause issues.
  + Bugfixes to saving and applying device settings.
  + Properly handle ^C when running in console.
* Thu Jun 27 2013 malcolmlewis@opensuse.org
- Initial build.
- Add 99-logitech-unifying-receiver.rules: openSUSE specific udev
  rule.
- Add solaar-fix-desktop-categories.patch: Fix desktop categories
  as per openSUSE desktop file specification.
